# Jing version 20091111

Copyright © 2001, 2002, 2003, 2008 Thai Open Source Software Center Ltd. Jing can be freely copied subject to these conditions.

This directory contains version 20091111 of Jing, a validator for RELAX NG and other schema languages.

The directory `bin` contains `jing.jar`, which contains the code for Jing, ready to use with a Java runtime. For more information on how to use Jing, see this document.

Apart from `jing.jar`, the `bin` directory contains some third-party jar files, which are used for XML parsing (under a pre-1.4 JRE that does not provide the Java XML parsing extension) and for validating with schema languages other than RELAX NG:

`saxon.jar`
  Comes from the Saxon 6.5.5 distribution. Used for Schematron 1.5 validation.
`xercesImpl.jar`
`xml-apis.jar`
  Come from the Xerces2 Java 2.9.1 distribution. Used for W3C XML Schema validation and for XML parsing. Xerces2 Java is under the Apache License Version 2.0, which requires the following notice:

         Apache Xerces Java
         Copyright 1999-2007 The Apache Software Foundation

         This product includes software developed at
         The Apache Software Foundation (http://www.apache.org/).

         Portions of this software were originally based on the following:
           - software copyright (c) 1999, IBM Corporation., http://www.ibm.com.
           - software copyright (c) 1999, Sun Microsystems., http://www.sun.com.
           - voluntary contributions made by Paul Eng on behalf of the
             Apache Software Foundation that were originally developed at iClick, Inc.,
             software copyright (c) 1999.

`isorelax.jar`
  Comes from ISO RELAX 2004/11/11 distribution. Provides a bridge to validators that use the JARV interface.

The file `src.zip` contains the Java source code. This is for reference purposes, and doesn't contain the supporting files, such as build scripts and test cases, that are needed for working conveniently with the source code. If you want to make changes to Jing, you should check out the source code and supporting files from the project's Subversion repository.